@@ -43,6 +43,7 @@ typedef struct MimeListState MimeListState;
 typedef struct ThumbnailState ThumbnailState;
 typedef struct MountState MountState;
 typedef struct FilesystemInfoState FilesystemInfoState;
+typedef struct FavoriteCheckState FavoriteCheckState;
 
 typedef enum {
 	REQUEST_LINK_INFO,
@@ -56,6 +57,7 @@ typedef enum {
 	REQUEST_MOUNT,
 	REQUEST_FILESYSTEM_INFO,
     REQUEST_BTIME,
+    REQUEST_FAVORITE_CHECK,
 	REQUEST_TYPE_LAST
 } RequestType;
 
@@ -125,6 +127,10 @@ struct NemoDirectoryDetails
     NemoFile *get_btime_file;
     GetBTimeState *get_btime_in_progress;
 
+    NemoFile *favorite_check_file;
+    FavoriteCheckState *favorite_check_in_progress;
+    guint favorite_check_idle_id;
+
 	NemoFile *extension_info_file;
 	NemoInfoProvider *extension_info_provider;
 	NemoOperationHandle *extension_info_in_progress;
@@ -141,7 +147,8 @@ struct NemoDirectoryDetails
 
 	GList *file_operations_in_progress; /* list of FileOperation * */
 
-	GHashTable *hidden_file_hash;
+    gint max_deferred_file_count;
+    gint early_load_file_count;
 };
 
 NemoDirectory *nemo_directory_get_existing                    (GFile                     *location);
@@ -239,9 +246,6 @@ void               nemo_directory_add_file_to_work_queue          (NemoDirectory
 void               nemo_directory_remove_file_from_work_queue     (NemoDirectory *directory,
 								       NemoFile *file);
 
-/* KDE compatibility hacks */
-
-void               nemo_set_kde_trash_name                        (const char *trash_dir);
 
 /* debugging functions */
 int                nemo_directory_number_outstanding              (void);
