@@ -33,9 +33,6 @@
 #define NORMAL_TEXT_WEIGHT PANGO_WEIGHT_NORMAL
 #define PINNED_TEXT_WEIGHT PANGO_WEIGHT_BOLD
 
-#define NEMO_SAVED_SEARCH_EXTENSION ".savedSearch"
-#define NEMO_SAVED_SEARCH_MIMETYPE "application/x-gnome-saved-search"
-
 #define DEFAULT_NEMO_DIRECTORY_MODE (0755)
 #define DEFAULT_DESKTOP_DIRECTORY_MODE (0755)
 
@@ -127,4 +124,6 @@ time_t nemo_query_btime_finish (GFile         *file,
                                 GAsyncResult  *res,
                                 GError       **error);
 
+gboolean nemo_treating_root_as_normal (void);
+gboolean nemo_user_is_root (void);
 #endif /* NEMO_FILE_UTILITIES_H */
