@@ -45,6 +45,7 @@ GSettings *nemo_tree_sidebar_preferences;
 GSettings *nemo_window_state;
 GSettings *nemo_plugin_preferences;
 GSettings *nemo_menu_config_preferences;
+GSettings *nemo_search_preferences;
 GSettings *gnome_lockdown_preferences;
 GSettings *gnome_background_preferences;
 GSettings *gnome_media_handling_preferences;
@@ -332,6 +333,7 @@ nemo_global_preferences_init (void)
 	nemo_tree_sidebar_preferences = g_settings_new("org.nemo.sidebar-panels.tree");
     nemo_plugin_preferences = g_settings_new("org.nemo.plugins");
     nemo_menu_config_preferences = g_settings_new("org.nemo.preferences.menu-config");
+    nemo_search_preferences = g_settings_new("org.nemo.search");
 	gnome_lockdown_preferences = g_settings_new("org.cinnamon.desktop.lockdown");
 	gnome_background_preferences = g_settings_new("org.cinnamon.desktop.background");
 	gnome_media_handling_preferences = g_settings_new("org.cinnamon.desktop.media-handling");
@@ -360,6 +362,7 @@ nemo_global_preferences_finalize (void)
     g_object_unref (nemo_tree_sidebar_preferences);
     g_object_unref (nemo_plugin_preferences);
     g_object_unref (nemo_menu_config_preferences);
+    g_object_unref (nemo_search_preferences);
     g_object_unref (gnome_lockdown_preferences);
     g_object_unref (gnome_background_preferences);
     g_object_unref (gnome_media_handling_preferences);
