@@ -47,7 +47,8 @@ enum {
 
 static GQuark attribute_name_q,
 	attribute_modification_date_q,
-	attribute_date_modified_q;
+	attribute_date_modified_q,
+    attribute_search_result_count_q;
 
 /* msec delay after Loading... dummy row turns into (empty) */
 #define LOADING_TO_EMPTY_DELAY 100
@@ -66,12 +67,15 @@ struct NemoListModelDetails {
 	GHashTable *directory_reverse_map; /* map from directory to GSequenceIter's */
 	GHashTable *top_reverse_map;	   /* map from files in top dir to GSequenceIter's */
 
+    NemoDirectory *view_dir;
+
 	int stamp;
 
 	GQuark sort_attribute;
 	GtkSortType order;
 
 	gboolean sort_directories_first;
+	gboolean sort_favorites_first;
 
 	GtkTreeView *drag_view;
 	int drag_begin_x;
@@ -444,8 +448,11 @@ nemo_list_model_get_value (GtkTreeModel *tree_model, GtkTreeIter *iter, int colu
 				      "attribute_q", &attribute,
 				      NULL);
 			if (file != NULL) {
-				str = nemo_file_get_string_attribute_with_default_q (file,
-											 attribute);
+                if (attribute == attribute_search_result_count_q) {
+                    str = nemo_file_get_search_result_count_as_string (file, (gpointer) model->details->view_dir);
+                } else {
+                    str = nemo_file_get_string_attribute_with_default_q (file, attribute);
+                }
 				g_value_take_string (value, str);
 			} else if (attribute == attribute_name_q) {
 				if (file_entry->parent->loaded) {
@@ -717,7 +724,9 @@ nemo_list_model_file_entry_compare_func (gconstpointer a,
 		result = nemo_file_compare_for_sort_by_attribute_q (file_entry1->file, file_entry2->file,
 									model->details->sort_attribute,
 									model->details->sort_directories_first,
-									(model->details->order == GTK_SORT_DESCENDING));
+									model->details->sort_favorites_first,
+									(model->details->order == GTK_SORT_DESCENDING),
+                                    model->details->view_dir);
 	} else if (file_entry1->file == NULL) {
 		return -1;
 	} else {
@@ -737,7 +746,9 @@ nemo_list_model_compare_func (NemoListModel *model,
 	result = nemo_file_compare_for_sort_by_attribute_q (file1, file2,
 								model->details->sort_attribute,
 								model->details->sort_directories_first,
-								(model->details->order == GTK_SORT_DESCENDING));
+								model->details->sort_favorites_first,
+								(model->details->order == GTK_SORT_DESCENDING),
+                                model->details->view_dir);
 
 	return result;
 }
@@ -1438,6 +1449,17 @@ nemo_list_model_set_should_sort_directories_first (NemoListModel *model, gboolea
 	nemo_list_model_sort (model);
 }
 
+void
+nemo_list_model_set_should_sort_favorites_first (NemoListModel *model, gboolean sort_favorites_first)
+{
+	if (model->details->sort_favorites_first == sort_favorites_first) {
+		return;
+	}
+
+	model->details->sort_favorites_first = sort_favorites_first;
+	nemo_list_model_sort (model);
+}
+
 int
 nemo_list_model_get_sort_column_id_from_attribute (NemoListModel *model,
 						       GQuark attribute)
@@ -1672,6 +1694,7 @@ nemo_list_model_class_init (NemoListModelClass *klass)
 	attribute_name_q = g_quark_from_static_string ("name");
 	attribute_modification_date_q = g_quark_from_static_string ("modification_date");
 	attribute_date_modified_q = g_quark_from_static_string ("date_modified");
+    attribute_search_result_count_q = g_quark_from_string ("search_result_count");
 
 	object_class = (GObjectClass *)klass;
 	object_class->finalize = nemo_list_model_finalize;
@@ -1851,3 +1874,10 @@ nemo_list_model_set_expanding (NemoListModel *model, NemoDirectory *directory)
     entry = g_sequence_get (ptr);
     entry->expanding = TRUE;
 }
+
+void
+nemo_list_model_set_view_directory (NemoListModel *model, NemoDirectory *dir)
+{
+    model->details->view_dir = dir;
+}
+
