@@ -220,6 +220,7 @@ desktop_location_changed_callback (gpointer user_data)
 
     g_object_unref (path_bar->priv->desktop_path);
     g_object_unref (path_bar->priv->home_path);
+    g_object_unref (path_bar->priv->root_path);
     path_bar->priv->desktop_path = nemo_get_desktop_location ();
     path_bar->priv->home_path = g_file_new_for_path (g_get_home_dir ());
     desktop_is_home = g_file_equal (path_bar->priv->home_path, path_bar->priv->desktop_path);
@@ -364,7 +365,7 @@ nemo_path_bar_init (NemoPathBar *path_bar)
 
     gtk_drag_dest_set (GTK_WIDGET (path_bar->priv->down_slider_button),
                0, NULL, 0, 0);
-    gtk_drag_dest_set_track_motion (GTK_WIDGET (path_bar->priv->up_slider_button), TRUE);
+    gtk_drag_dest_set_track_motion (GTK_WIDGET (path_bar->priv->down_slider_button), TRUE);
     g_signal_connect (path_bar->priv->down_slider_button,
               "drag-motion",
               G_CALLBACK (nemo_path_bar_slider_drag_motion),
@@ -400,6 +401,7 @@ nemo_path_bar_finalize (GObject *object)
     g_clear_object (&path_bar->priv->xdg_public_path);
     g_clear_object (&path_bar->priv->xdg_templates_path);
     g_clear_object (&path_bar->priv->xdg_videos_path);
+    g_clear_object (&path_bar->priv->desktop_path);
 
     g_signal_handlers_disconnect_by_func (nemo_preferences,
                           desktop_location_changed_callback,
@@ -444,20 +446,15 @@ nemo_path_bar_get_preferred_width (GtkWidget *widget,
     ButtonData *button_data;
     NemoPathBar *path_bar;
     GList *list;
-    gint child_height;
-    gint height;
     gint child_min, child_nat;
 
     path_bar = NEMO_PATH_BAR (widget);
 
     *minimum = *natural = 0;
-    height = 0;
 
     for (list = path_bar->priv->button_list; list; list = list->next) {
         button_data = BUTTON_DATA (list->data);
         gtk_widget_get_preferred_width (button_data->button, &child_min, &child_nat);
-        gtk_widget_get_preferred_height (button_data->button, &child_height, NULL);
-        height = MAX (height, child_height);
         *minimum = MAX (*minimum, child_min);
         *natural = MAX (*natural, child_nat);
     }
@@ -1605,6 +1602,7 @@ setup_file_path_mounted_mount (GFile *location, ButtonData *button_data)
         g_object_unref (root);
     }
     g_list_free_full (mounts, g_object_unref);
+    g_object_unref (volume_monitor);
     return result;
 }
 
