@@ -958,6 +958,7 @@ static void
 copy_or_cut_files (FMTreeView *view,
 		   gboolean cut)
 {
+    GtkClipboard *clipboard;
 	char *status_string, *name;
 	NemoClipboardInfo info;
         GtkTargetList *target_list;
@@ -975,11 +976,14 @@ copy_or_cut_files (FMTreeView *view,
         targets = gtk_target_table_new_from_list (target_list, &n_targets);
         gtk_target_list_unref (target_list);
 
-	gtk_clipboard_set_with_data (nemo_clipboard_get (GTK_WIDGET (view->details->tree_widget)),
-				     targets, n_targets,
-				     nemo_get_clipboard_callback, nemo_clear_clipboard_callback,
-				     NULL);
-        gtk_target_table_free (targets, n_targets);
+    clipboard = nemo_clipboard_get (GTK_WIDGET (view));
+
+    gtk_clipboard_set_with_data (clipboard,
+                                 targets, n_targets,
+                                 nemo_get_clipboard_callback, nemo_clear_clipboard_callback,
+                                 NULL);
+    gtk_clipboard_set_can_store (clipboard, NULL, 0);
+    gtk_target_table_free (targets, n_targets);
 
 	nemo_clipboard_monitor_set_clipboard_info (nemo_clipboard_monitor_get (),
 	                                               &info);
