@@ -285,7 +285,7 @@ viewed_file_changed_callback (NemoFile *file,
         if (slot->back_list == NULL) {
             end_location_change (slot);
             gtk_widget_destroy (GTK_WIDGET (slot->content_view));
-            nemo_window_close (nemo_window_slot_get_window (slot));
+            nemo_window_pane_close_slot (slot->pane, slot);
             return;
         }
 
@@ -1490,11 +1490,12 @@ update_for_new_location (NemoWindowSlot *slot)
 
 	if (slot == nemo_window_get_active_slot (window)) {
 		/* Sync up and zoom action states */
-		nemo_window_sync_up_button (window);
+		nemo_window_pane_sync_up_actions (slot->pane);
 		nemo_window_sync_zoom_widgets (window);
         nemo_window_sync_bookmark_action (window);
         nemo_window_sync_view_type (window);
         nemo_window_sync_thumbnail_action(window);
+        nemo_window_sync_create_folder_button (window);
 
 		/* Load menus from nemo extensions for this location */
 		nemo_window_load_extension_menus (window);
