@@ -49,6 +49,7 @@
 #include <gio/gio.h>
 #include <glib/gi18n.h>
 
+#include <eel/eel-vfs-extensions.h>
 #include <eel/eel-gtk-extensions.h>
 #include <eel/eel-stock-dialogs.h>
 
@@ -68,6 +69,7 @@
 
 #define MENU_PATH_EXTENSION_ACTIONS                     "/MenuBar/File/Extension Actions"
 #define POPUP_PATH_EXTENSION_ACTIONS                     "/background/Before Zoom Items/Extension Actions"
+#define MENU_BAR_PATH                                    "/MenuBar"
 
 #define NETWORK_URI          "network:"
 #define COMPUTER_URI         "computer:"
@@ -586,36 +588,6 @@ action_show_hide_sidebar_callback (GtkAction *action,
 	}
 }
 
-static void
-action_split_view_callback (GtkAction *action,
-			    gpointer user_data)
-{
-	NemoWindow *window;
-	gboolean is_active;
-
-    if (NEMO_IS_DESKTOP_WINDOW (user_data)) {
-        return;
-    }
-
-	window = NEMO_WINDOW (user_data);
-
-	is_active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
-	if (is_active != nemo_window_split_view_showing (window)) {
-		NemoWindowSlot *slot;
-
-		if (is_active) {
-			nemo_window_split_view_on (window);
-		} else {
-			nemo_window_split_view_off (window);
-		}
-
-		slot = nemo_window_get_active_slot (window);
-		if (slot != NULL) {
-			nemo_view_update_menus (slot->content_view);
-		}
-	}
-}
-
 static void
 nemo_window_update_split_view_actions_sensitivity (NemoWindow *window)
 {
@@ -662,6 +634,38 @@ nemo_window_update_split_view_actions_sensitivity (NemoWindow *window)
 	g_clear_object (&next_pane_location);
 }
 
+static void
+action_split_view_callback (GtkAction *action,
+			    gpointer user_data)
+{
+	NemoWindow *window;
+	gboolean is_active;
+
+    if (NEMO_IS_DESKTOP_WINDOW (user_data)) {
+        return;
+    }
+
+	window = NEMO_WINDOW (user_data);
+
+	is_active = gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action));
+	if (is_active != nemo_window_split_view_showing (window)) {
+		NemoWindowSlot *slot;
+
+		if (is_active) {
+			nemo_window_split_view_on (window);
+		} else {
+			nemo_window_split_view_off (window);
+		}
+
+		slot = nemo_window_get_active_slot (window);
+		if (slot != NULL) {
+			nemo_view_update_menus (slot->content_view);
+		}
+	}
+
+    nemo_window_update_split_view_actions_sensitivity (window);
+}
+
 static void
 sidebar_radio_entry_changed_cb (GtkAction *action,
                 GtkRadioAction *current,
@@ -1135,6 +1139,20 @@ menu_set_show_thumbnails_action (gboolean value, NemoWindow *window)
                            NULL);
 }
 
+void
+toolbar_set_create_folder_button (gboolean value, NemoWindowPane *pane)
+{
+    GtkActionGroup *action_group;
+    GtkAction *action;
+
+    action_group = nemo_window_pane_get_toolbar_action_group (pane);
+
+    action = gtk_action_group_get_action(action_group,
+                                         NEMO_ACTION_NEW_FOLDER);
+
+    gtk_action_set_sensitive (action, value);
+}
+
 void
 menu_set_view_selection (guint action_id,
                          NemoWindow *window)
@@ -1270,8 +1288,26 @@ action_open_terminal_callback(GtkAction *action, gpointer callback_data)
     g_object_unref (gfile);
 }
 
+static void
+file_menu_bar_item_activated (GtkAction *action, gpointer user_data)
+{
+    NemoWindow *window;
+    NemoView *view;
+
+    window = NEMO_WINDOW (user_data);
+
+    if (window->details->dynamic_menu_entries_current) {
+        return;
+    }
+
+    view = get_current_view (window);
+    nemo_view_update_actions_and_extensions (view);
+
+    window->details->dynamic_menu_entries_current = TRUE;
+}
+
 static const GtkActionEntry main_entries[] = {
-  /* name, stock id, label */  { "File", NULL, N_("_File") },
+  /* name, stock id, label */  { "File", NULL, N_("_File"), NULL, NULL, G_CALLBACK (file_menu_bar_item_activated) },
   /* name, stock id, label */  { "Edit", NULL, N_("_Edit") },
   /* name, stock id, label */  { "View", NULL, N_("_View") },
   /* name, stock id, label */  { "Help", NULL, N_("_Help") },
@@ -1407,7 +1443,7 @@ static const GtkActionEntry main_entries[] = {
 				 "F6", N_("Move focus to the other pane in a split view window"),
 				 G_CALLBACK (action_split_view_switch_next_pane_callback) },
   /* name, stock id, label */  { "SplitViewSameLocation", NULL, N_("Sa_me Location as Other Pane"),
-				 NULL, N_("Go to the same location as in the extra pane"),
+				 "<alt>S", N_("Go to the same location as in the extra pane"),
 				 G_CALLBACK (action_split_view_same_location_callback) },
   /* name, stock id, label */  { "Add Bookmark", "bookmark-new-symbolic", N_("_Add Bookmark"),
                                  "<control>d", N_("Add a bookmark for the current location to this menu"),
@@ -1458,7 +1494,7 @@ static const GtkToggleActionEntry main_toggle_entries[] = {
   /* is_active */            TRUE },
   /* name, stock id */     { "Search", "edit-find-symbolic",
   /* label, accelerator */   N_("_Search for Files..."), "<control>f",
-  /* tooltip */              N_("Search documents and folders by name"),
+  /* tooltip */              N_("Search documents and folders"),
 			     NULL,
   /* is_active */            FALSE },
   /* name, stock id */     { NEMO_ACTION_SHOW_HIDE_EXTRA_PANE, NULL,
@@ -1668,7 +1704,7 @@ nemo_window_create_toolbar_action_group (NemoWindow *window)
    	g_object_unref (action);
 
  	action = GTK_ACTION (gtk_toggle_action_new (NEMO_ACTION_SEARCH,
- 				_("Search"),_("Search documents and folders by name"),
+ 				_("Search"),_("Search documents and folders"),
  				NULL));
 
   	gtk_action_group_add_action (action_group, action);
@@ -1760,6 +1796,16 @@ nemo_window_initialize_actions (NemoWindow *window)
 			  NULL);
 }
 
+static void
+menu_bar_deactivated (GtkMenuShell *menu, gpointer user_data)
+{
+    NemoWindow *window;
+
+    window = NEMO_WINDOW (user_data);
+
+    window->details->dynamic_menu_entries_current = FALSE;
+}
+
 /**
  * nemo_window_initialize_menus
  *
@@ -1771,6 +1817,7 @@ nemo_window_initialize_menus (NemoWindow *window)
 {
 	GtkActionGroup *action_group;
 	GtkUIManager *ui_manager;
+    GtkWidget *menubar;
 	GtkAction *action;
       GtkAction *action_to_hide;
 	gint i;
@@ -1789,16 +1836,18 @@ nemo_window_initialize_menus (NemoWindow *window)
 				      window);
 
       /* if root then hide menu items that do not work */
-      if (geteuid() == 0) {
-          action_to_hide = gtk_action_group_get_action (action_group, "Go to Computer");
-          gtk_action_set_visible (action_to_hide, FALSE);
-          action_to_hide = gtk_action_group_get_action (action_group, "Go to Templates");
-          gtk_action_set_visible (action_to_hide, FALSE);
-          action_to_hide = gtk_action_group_get_action (action_group, "Go to Trash");
-          gtk_action_set_visible (action_to_hide, FALSE);
-          action_to_hide = gtk_action_group_get_action (action_group, "Go to Network");
-          gtk_action_set_visible (action_to_hide, FALSE);
-      }
+    if (nemo_user_is_root () && !nemo_treating_root_as_normal ()) {
+        action_to_hide = gtk_action_group_get_action (action_group, "Go to Templates");
+        gtk_action_set_visible (action_to_hide, FALSE);
+    }
+
+    /* hide menu items that are not currently supported by the vfs */
+    action_to_hide = gtk_action_group_get_action (action_group, "Go to Computer");
+    gtk_action_set_visible (action_to_hide, eel_vfs_supports_uri_scheme ("computer"));
+    action_to_hide = gtk_action_group_get_action (action_group, "Go to Trash");
+    gtk_action_set_visible (action_to_hide, eel_vfs_supports_uri_scheme ("trash"));
+    action_to_hide = gtk_action_group_get_action (action_group, "Go to Network");
+    gtk_action_set_visible (action_to_hide, eel_vfs_supports_uri_scheme ("network"));
 
 	gtk_action_group_add_toggle_actions (action_group,
 					     main_toggle_entries, G_N_ELEMENTS (main_toggle_entries),
@@ -1872,6 +1921,14 @@ nemo_window_initialize_menus (NemoWindow *window)
 	/* add the UI */
 	gtk_ui_manager_add_ui_from_resource (ui_manager, "/org/nemo/nemo-shell-ui.xml", NULL);
 
+    // window->details->menubar isn't set yet
+    menubar = gtk_ui_manager_get_widget (window->details->ui_manager, "/MenuBar");
+
+    g_signal_connect (menubar,
+                      "deactivate",
+                      G_CALLBACK (menu_bar_deactivated),
+                      window);
+
 	nemo_window_initialize_trash_icon_monitor (window);
 }
 
