@@ -563,7 +563,7 @@ hide_menu_on_delay (NemoWindow *window)
 }
 
 static gboolean
-on_menu_focus_out (GtkWidget *widget,
+on_menu_focus_out (GtkMenuShell *widget,
                    GdkEvent  *event,
                    gpointer   user_data)
 {
@@ -577,11 +577,26 @@ on_menu_focus_out (GtkWidget *widget,
      * complete their click action. */
     clear_menu_hide_delay (window);
 
-    window->details->menu_hide_delay_id = g_timeout_add (200, (GSourceFunc) hide_menu_on_delay, window);
+    /* When a submenu pops-up, the menu loses focus. The menu should disappear
+     * only when none of its elements is selected. */
+    if (!gtk_menu_shell_get_selected_item (widget)) {
+        window->details->menu_hide_delay_id = g_timeout_add (200, (GSourceFunc) hide_menu_on_delay, window);
+    }
 
     return GDK_EVENT_PROPAGATE;
 }
 
+void
+on_menu_selection_done (GtkMenuShell *menushell,
+                        gpointer      user_data)
+{
+	NemoWindow *window = NEMO_WINDOW (user_data);
+
+	/* Remove the menu inmediately after selecting an item. */
+	clear_menu_hide_delay (window);
+	window->details->menu_hide_delay_id = g_timeout_add (0, (GSourceFunc) hide_menu_on_delay, window);
+}
+
 static void
 nemo_window_constructed (GObject *self)
 {
@@ -629,6 +644,12 @@ nemo_window_constructed (GObject *self)
                              window,
                              0);
 
+    g_signal_connect_object (menu,
+                             "selection-done",
+                             G_CALLBACK (on_menu_selection_done),
+                             window,
+                             0);
+
 	if (g_settings_get_boolean (nemo_window_state, NEMO_WINDOW_STATE_START_WITH_MENU_BAR)){
 		gtk_widget_show (menu);
 	} else {
@@ -1173,7 +1194,7 @@ nemo_window_key_press_event (GtkWidget *widget,
           return FALSE;
       }
 
-	if (view != NULL && nemo_view_get_is_renaming (view)) {
+	if (view != NULL && nemo_view_get_is_renaming (view) && event->keyval != GDK_KEY_F2) {
 		/* if we're renaming, just forward the event to the
 		 * focused widget and return. We don't want to process the window
 		 * accelerator bindings, as they might conflict with the
@@ -1340,35 +1361,6 @@ nemo_window_sync_menu_bar (NemoWindow *window)
     }
 }
 
-void
-nemo_window_sync_up_button (NemoWindow *window)
-{
-	GtkAction *action;
-	GtkActionGroup *action_group;
-	NemoWindowSlot *slot;
-	gboolean allowed;
-	GFile *parent;
-
-	slot = nemo_window_get_active_slot (window);
-
-	allowed = FALSE;
-	if (slot->location != NULL) {
-		parent = g_file_get_parent (slot->location);
-		allowed = parent != NULL;
-
-		g_clear_object (&parent);
-	}
-
-	action_group = nemo_window_get_main_action_group (window);
-
-	action = gtk_action_group_get_action (action_group,
-					      NEMO_ACTION_UP);
-	gtk_action_set_sensitive (action, allowed);
-	action = gtk_action_group_get_action (action_group,
-					      NEMO_ACTION_UP_ACCEL);
-	gtk_action_set_sensitive (action, allowed);
-}
-
 void
 nemo_window_sync_title (NemoWindow *window,
 			    NemoWindowSlot *slot)
@@ -1528,6 +1520,21 @@ nemo_window_sync_thumbnail_action (NemoWindow *window)
                                slot);
 }
 
+void
+nemo_window_sync_create_folder_button (NemoWindow *window)
+{
+    NemoWindowSlot *slot;
+    gboolean allow;
+
+    slot = nemo_window_get_active_slot (window);
+
+    allow = nemo_file_can_write (slot->viewed_file) &&
+            !nemo_file_is_in_favorites (slot->viewed_file) &&
+            !nemo_file_is_in_trash (slot->viewed_file);
+
+    toolbar_set_create_folder_button (allow, slot->pane);
+}
+
 static void
 zoom_level_changed_callback (NemoView *view,
                              NemoWindow *window)
